'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var core = require('@vueuse/core');
var Message = require('./Message.js');

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !vue.isVNode(s);
}
let seed = 0;
function getUUID() {
  return "___" + seed++;
}
const messageManagerProps = {
  prefixCls: String,
  max: Number
};
const MessageManager = vue.defineComponent({
  name: "message-manager",
  props: messageManagerProps,
  setup(props, {
    expose
  }) {
    const msgListRef = vue.ref([]);
    function add(options) {
      var _a;
      const key = (_a = options == null ? void 0 : options.key) != null ? _a : getUUID();
      const msg = __spreadProps(__spreadValues({}, options), {
        key,
        close: () => remove(key)
      });
      const i = msgListRef.value.findIndex((msg2) => msg2.key === key);
      if (~i) {
        msgListRef.value.splice(i, 1, msg);
      } else {
        if (msgListRef.value.length >= props.max) {
          msgListRef.value.shift();
        }
        msgListRef.value.push(msg);
      }
      return msg;
    }
    function remove(key) {
      const i = msgListRef.value.findIndex((msg) => msg.key === key);
      if (~i)
        msgListRef.value.splice(i, 1);
    }
    function removeAll() {
      msgListRef.value = [];
    }
    expose({
      add,
      remove,
      removeAll
    });
    return () => {
      let _slot;
      const {
        prefixCls
      } = props;
      const cls = `${prefixCls}-container`;
      return vue.createVNode(vue.TransitionGroup, {
        "tag": "div",
        "name": prefixCls,
        "class": cls
      }, _isSlot(_slot = msgListRef.value.map((msg) => vue.createVNode(Message, vue.mergeProps(msg, {
        "onClose": () => remove(msg.key)
      }), null))) ? _slot : {
        default: () => [_slot]
      });
    };
  }
});
function newInstace(props) {
  const div = document.createElement("div");
  const container = core.unrefElement(props.to) || document.body;
  container.appendChild(div);
  const instRef = vue.ref();
  const app = vue.createApp({
    render: () => vue.createVNode(MessageManager, vue.mergeProps(props, {
      "ref": instRef
    }), null)
  });
  app.mount(div);
  return instRef.value;
}

exports["default"] = MessageManager;
exports.messageManagerProps = messageManagerProps;
exports.newInstace = newInstace;
