'use strict';

var vue = require('vue');
require('../_util/hooks/index.js');
var index = require('../sunken/index.js');
require('../icon/index.js');
var useNameSpace = require('../_util/hooks/useNameSpace2.js');
var Icon = require('../icon/Icon.js');

const Button = vue.defineComponent({
  name: "x-button",
  props: {
    type: {
      type: String,
      default: "default"
    },
    tag: {
      type: String,
      default: "button"
    },
    dashed: Boolean,
    circle: Boolean,
    round: Boolean,
    ghost: Boolean,
    link: Boolean,
    block: Boolean,
    disabled: Boolean,
    href: String,
    target: String,
    autofocus: Boolean,
    loading: Boolean
  },
  emits: ["click"],
  directives: {
    [index.name]: index
  },
  setup(props, {
    slots,
    emit
  }) {
    const ns = useNameSpace("btn");
    const btnRef = vue.ref();
    if (props.autofocus) {
      vue.onMounted(() => {
        btnRef.value.focus();
      });
    }
    const disabledRef = vue.computed(() => props.disabled || props.loading);
    function onClick(e) {
      if (disabledRef.value) {
        e.preventDefault();
        return;
      }
      emit("click", e);
    }
    return () => {
      const {
        tag,
        loading
      } = props;
      const disabled = disabledRef.value;
      const buttonProps = {
        ref: btnRef,
        class: {
          [ns.b()]: true,
          [ns.m(props.type)]: true,
          [ns.m("dashed")]: props.dashed,
          [ns.m("circle")]: props.circle,
          [ns.m("round")]: props.round,
          [ns.m("ghost")]: props.ghost || props.dashed,
          [ns.m("link")]: props.link,
          [ns.m("block")]: props.block,
          [ns.m("disabled")]: props.disabled,
          [ns.m("only-icon")]: !slots.default
        },
        disabled,
        onClick
      };
      return vue.withDirectives(vue.createVNode(tag, buttonProps, {
        default: () => {
          var _a;
          return [loading && vue.createVNode(Icon["default"], {
            "type": "loading",
            "spin": true,
            "class": ns.e("icon")
          }, null), (_a = slots.default) == null ? void 0 : _a.call(slots)];
        }
      }), [[vue.resolveDirective("sunken")]]);
    };
  }
});
Button.install = (app) => {
  app.component(Button.name, Button);
};

module.exports = Button;
