'use strict';

var vue = require('vue');
var useMemo = require('../_util/hooks/useMemo.js');
var _ = require('../_util/_.js');
require('./index.js');
var Calendar = require('./Calendar.js');

var RangeCalendar = vue.defineComponent({
  name: "x-range-calendar",
  props: {
    value: Array,
    disabledDate: Function,
    onSelect: Function
  },
  emits: ["update:value", "change"],
  setup(props, {
    emit
  }) {
    const valueRef = useMemo(() => _.castArray(props.value));
    const hoverValueRef = vue.ref([]);
    function onHover(date) {
      if (valueRef.value.length == 1) {
        hoverValueRef.value = [valueRef.value[0], date].sort((a, b) => +a - +b);
      }
    }
    function onSelect(date) {
      var _a;
      let val = valueRef.value;
      if (val.length == 1) {
        val[1] = date.clone();
        val.sort((a, b) => +a - +b);
        hoverValueRef.value = [];
        emit("update:value", [...val]);
      } else {
        val = valueRef.value = [date.clone()];
      }
      emit("change", [...val]);
      if (val[0] && val[1]) {
        (_a = props.onSelect) == null ? void 0 : _a.call(props, val);
      }
    }
    return () => {
      const calendarProps = {
        range: hoverValueRef.value.length ? hoverValueRef.value : valueRef.value,
        disabledDate: props.disabledDate,
        onHover,
        onSelect
      };
      return vue.createVNode(Calendar.DateCalendar, calendarProps, null);
    };
  }
});

module.exports = RangeCalendar;
