'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var index = require('../_util/props-util/index.js');
require('../_util/hooks/index.js');
var normalizeOptions = require('../_util/normalizeOptions.js');
var Checkbox = require('./Checkbox.js');
var useMemo = require('../_util/hooks/useMemo.js');

const checkboxGroupContext = Symbol("checkboxGroupContext");
const prefixCls = "x-checkbox-group";
var Group = vue.defineComponent({
  name: prefixCls,
  props: {
    name: String,
    options: Array,
    value: Array,
    vertical: Boolean,
    disabled: Boolean
  },
  emits: ["update:value", "change"],
  setup(props, {
    emit
  }) {
    const {
      proxy: vm
    } = vue.getCurrentInstance();
    const val = useMemo(() => props.value);
    function toggleOption(opt) {
      const value = [...val.value];
      const i = value.indexOf(opt.value);
      if (i > -1) {
        value.splice(i, 1);
      } else {
        value.push(opt.value);
      }
      emit("update:value", value);
      emit("change", value);
    }
    vue.provide(checkboxGroupContext, {
      disabledRef: vue.toRef(props, "disabled"),
      nameRef: vue.toRef(props, "name"),
      valueRef: vue.toRef(val, "value"),
      toggleOption
    });
    return () => {
      var _a;
      let children;
      if ((_a = props.options) == null ? void 0 : _a.length) {
        children = normalizeOptions.mapOptions(props.options, (opt) => vue.createVNode(Checkbox, {
          "key": opt.value,
          "checked": val.value.indexOf(opt.value) != -1,
          "name": props.name,
          "value": opt.value,
          "disabled": opt.disabled || props.disabled,
          "style": opt.style
        }, {
          default: () => [opt.label]
        }));
      } else {
        children = index.getSlot(vm);
      }
      const cls = [prefixCls, props.vertical && `${prefixCls}-vertical`];
      return vue.createVNode("div", {
        "class": cls
      }, [children]);
    };
  }
});

exports.checkboxGroupContext = checkboxGroupContext;
exports["default"] = Group;
