'use strict';

var vue = require('vue');
var useMemo = require('../_util/hooks/useMemo.js');
var utils = require('./utils.js');
require('../trigger/index.js');
require('../icon/index.js');
var RangeCalendar = require('../calendar/RangeCalendar.js');
var props = require('./props.js');
var Icon = require('../icon/Icon.js');
var Trigger = require('../trigger/Trigger.js');

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var rangePicker = vue.defineComponent({
  name: "x-range-picker",
  props: __spreadProps(__spreadValues({}, props.PickerProps), {
    prefixCls: {
      default: "x-range-picker"
    },
    value: Array,
    placeholder: {
      default: ["\u5F00\u59CB\u65E5\u671F", "\u7ED3\u675F\u65E5\u671F"]
    }
  }),
  emits: ["update:value", "change"],
  setup(props, {
    emit
  }) {
    const state = vue.reactive({
      opend: false,
      focued: false
    });
    const inputRef1 = vue.ref();
    const placeholderRef = vue.computed(() => {
      const {
        placeholder
      } = props;
      return Array.isArray(placeholder) ? placeholder : [placeholder, placeholder];
    });
    const valueRef = useMemo(() => utils.toMoment(props.value, props.valueFormat) || []);
    function onChange(date) {
      valueRef.value = date == null ? void 0 : date.map((e) => e.clone());
      const val = props.valueFormat ? utils.formatDate(date, props.valueFormat) : date == null ? void 0 : date.map((e) => e.clone());
      emit("update:value", val);
      emit("change", val);
    }
    function onSelect(date) {
      state.opend = false;
      onChange(date);
    }
    function onClear(e) {
      e.stopPropagation();
      onSelect([]);
    }
    function onClick(e) {
      if (props.disabled)
        return;
      requestAnimationFrame(() => inputRef1.value.focus());
    }
    function onPopupVisibleChange(visble) {
      state.opend = visble;
    }
    function onFocus() {
      state.focued = true;
    }
    function onBlur() {
      state.focued = false;
    }
    let calendarNode;
    function getCalendarNode() {
      if (!state.opend)
        return calendarNode;
      const calendarProps = {
        value: valueRef.value,
        disabledDate: props.disabledDate,
        onSelect
        // onChange
      };
      calendarNode = vue.createVNode(RangeCalendar, calendarProps, null);
      return calendarNode;
    }
    return () => {
      const {
        prefixCls,
        format,
        disabled,
        clearable
      } = props;
      const placeholder = placeholderRef.value;
      const val = valueRef.value;
      const cls = {
        [prefixCls]: true,
        [`${prefixCls}-focus`]: state.focued,
        [`${prefixCls}-disabled`]: disabled
      };
      const triggerProps = {
        prefixCls: `${prefixCls}-popup`,
        popup: getCalendarNode(),
        popupVisible: state.opend,
        action: disabled ? "" : "click",
        popupAlign: {
          points: ["tl", "bl"]
        },
        onPopupVisibleChange
      };
      const inputProps = {
        class: `${prefixCls}_input`,
        disabled,
        onFocus,
        onBlur
      };
      const clearIcon = !disabled && clearable && val.length ? vue.createVNode(Icon["default"], {
        "class": `${prefixCls}_clear`,
        "type": "cross",
        "onClick": onClear,
        "onMousedown": onClick
      }, null) : void 0;
      const calendarIcon = clearIcon ? void 0 : vue.createVNode(Icon["default"], {
        "class": `${prefixCls}_icon`,
        "type": "calendar",
        "onMousedown": onClick
      }, null);
      return vue.createVNode(Trigger, triggerProps, {
        default: () => [vue.createVNode("div", {
          "class": cls
        }, [vue.createVNode("input", vue.mergeProps(inputProps, {
          "placeholder": placeholder[0],
          "value": utils.formatDate(val[0], format),
          "ref": inputRef1
        }), null), vue.createVNode("span", {
          "class": `${prefixCls}_separator`
        }, [vue.createTextVNode(" ~ ")]), vue.createVNode("input", vue.mergeProps(inputProps, {
          "placeholder": placeholder[1],
          "value": utils.formatDate(val[1], format)
        }), null), calendarIcon, clearIcon])]
      });
    };
  }
});

module.exports = rangePicker;
