'use strict';

var vue = require('vue');
var index = require('../_util/props-util/index.js');

function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !vue.isVNode(s);
}
const preCls = "x-drawer";
const Drawer = vue.defineComponent({
  name: preCls,
  props: {
    title: String,
    visible: Boolean,
    width: {
      type: [Number, String],
      default: 396
    },
    mask: {
      type: Boolean,
      default: true
    },
    maskClosable: {
      type: Boolean,
      default: true
    },
    to: {
      type: [String, Object],
      default: "body"
    }
  },
  inheritAttrs: false,
  emits: ["update:visible"],
  setup(props, {
    attrs,
    emit
  }) {
    const {
      proxy: vm
    } = vue.getCurrentInstance();
    function onClose() {
      setVisible(false);
    }
    function onMaskClick() {
      if (!props.maskClosable)
        return;
      onClose();
    }
    function setVisible(visible) {
      emit("update:visible", visible);
    }
    const isMounted = vue.ref(false);
    vue.onMounted(() => {
      isMounted.value = true;
    });
    const headerRef = vue.computed(() => {
      var _a;
      let title = index.getComponent(vm, "title");
      let header = (_a = index.getComponent(vm, "header")) == null ? void 0 : _a[0];
      if (!header && !title)
        return void 0;
      const extraProps = {
        class: `${preCls}_header`
      };
      if (header) {
        header = vue.cloneVNode(header, extraProps);
      } else {
        header = vue.createVNode("div", extraProps, [vue.createVNode("div", {
          "class": `${preCls}_title`
        }, [title])]);
      }
      return header;
    });
    const footerRef = vue.computed(() => {
      const footer = index.getComponent(vm, "footer");
      if (!footer)
        return void 0;
      return vue.createVNode("div", {
        "class": `${preCls}_footer`
      }, [footer]);
    });
    return () => {
      if (!isMounted.value)
        return;
      const {
        mask: hasMask,
        to,
        visible,
        width
      } = props;
      const body = vue.createVNode("div", {
        "class": `${preCls}_body`
      }, [index.getSlot(vm)]);
      const mask = hasMask ? vue.withDirectives(vue.createVNode("div", {
        "class": `${preCls}_mask`,
        "onClick": onMaskClick
      }, null), [[vue.vShow, visible]]) : void 0;
      const clazz = [preCls, {
        [`${preCls}-open`]: visible,
        [`${preCls}-glass`]: visible
      }];
      return vue.createVNode(vue.Teleport, {
        "to": to
      }, {
        default: () => [vue.createVNode("div", vue.mergeProps({
          "class": clazz
        }, attrs), [vue.createVNode(vue.Transition, {
          "name": "fade"
        }, _isSlot(mask) ? mask : {
          default: () => [mask]
        }), vue.createVNode("div", {
          "class": `${preCls}_wrapper`,
          "style": {
            width: width + "px"
          }
        }, [headerRef.value, body, footerRef.value])])]
      });
    };
  }
});
Drawer.install = (app) => {
  app.component(Drawer.name, Drawer);
};

module.exports = Drawer;
