'use strict';

var isValid = require('../_util/isValid.js');

function get(num, origin) {
  let size = typeof num === "function" ? num(origin) : num;
  return size + "px";
}
function useExpandTransition(props) {
  return {
    onEnter: (el) => {
      el.style.transition = `none`;
      el.style[props.heightProp] = "";
      el.style[props.widthProp] = "";
      const height = el.offsetHeight, width = el.offsetWidth;
      if (isValid(props.height))
        el.style[props.heightProp] = get(props.height, height);
      if (isValid(props.width))
        el.style[props.widthProp] = get(props.width, width);
      void el.offsetWidth;
      el.style.transition = ``;
      if (isValid(props.height))
        el.style[props.heightProp] = `${height}px`;
      if (isValid(props.width))
        el.style[props.widthProp] = `${width}px`;
      void el.offsetWidth;
    },
    onAfterEnter: (el) => {
      el.style[props.heightProp] = ``;
      el.style[props.widthProp] = ``;
    },
    onBeforeLeave: (el) => {
      if (isValid(props.height))
        el.style[props.heightProp] = `${el.offsetHeight}px`;
      if (isValid(props.width))
        el.style[props.widthProp] = `${el.offsetWidth}px`;
      void el.offsetWidth;
    },
    onLeave: (el) => {
      const height = el.offsetHeight, width = el.offsetWidth;
      if (isValid(props.height))
        el.style[props.heightProp] = get(props.height, height);
      if (isValid(props.width))
        el.style[props.widthProp] = get(props.width, width);
      void el.offsetWidth;
    },
    onAfterLeave: (el) => {
      el.style[props.heightProp] = ``;
      el.style[props.widthProp] = ``;
    }
  };
}

module.exports = useExpandTransition;
