'use strict';

var vue = require('vue');
var index = require('../_util/props-util/index.js');
require('../_util/css/index.js');
var getScrollParent = require('../_util/Dom/getScrollParent.js');
var formatLength = require('../_util/css/format-length.js');

const preCls = "x-image";
var Image = vue.defineComponent({
  name: preCls,
  props: {
    src: String,
    width: [String, Number],
    height: [String, Number],
    fit: String,
    alt: String,
    placeholder: [Boolean, Object, String],
    fallback: String,
    lazy: Boolean
  },
  emits: ["load", "error"],
  setup(props, {
    emit,
    slots
  }) {
    const {
      proxy: vm
    } = vue.getCurrentInstance();
    const hasPlaceholder = vue.computed(() => !!props.placeholder || !!slots.placeholder);
    const statusRef = vue.ref();
    vue.watch(() => props.src, () => {
      statusRef.value = hasPlaceholder.value ? "loading" : "normal";
    }, {
      immediate: true
    });
    const showRef = vue.ref(!props.lazy);
    let io;
    vue.onMounted(() => {
      if (!props.lazy)
        return;
      const el = index.findDOMNode(vm);
      io = new IntersectionObserver(([entry]) => {
        if (!entry.isIntersecting)
          return;
        showRef.value = true;
        io.disconnect();
        io = void 0;
      }, {
        root: getScrollParent.getScrollParent(el)
      });
      io.observe(el);
    });
    vue.onBeforeUnmount(() => {
      io == null ? void 0 : io.disconnect();
    });
    function onLoad(e) {
      statusRef.value = "normal";
      emit("load", e);
    }
    function onError(e) {
      statusRef.value = "error";
      emit("error", e);
    }
    function getImg() {
      if (!showRef.value)
        return;
      const imgProps = {
        class: `${preCls}_img`,
        style: {
          objectFit: props.fit
        },
        alt: props.alt,
        src: props.src,
        onLoad,
        onError
      };
      return vue.createVNode("img", imgProps, null);
    }
    function getPlaceholder() {
      if (!hasPlaceholder.value)
        return;
      return vue.createVNode("div", {
        "class": `${preCls}_placeholder`
      }, [props.placeholder !== true ? index.getComponent(vm, "placeholder") : "\u52A0\u8F7D\u4E2D\u2026\u2026"]);
    }
    function getError() {
      var _a;
      if (props.fallback) {
        return vue.createVNode("img", {
          "class": `${preCls}_error`,
          "src": props.fallback
        }, null);
      } else {
        return vue.createVNode("div", {
          "class": `${preCls}_error`
        }, [((_a = slots.error) == null ? void 0 : _a.call(slots)) || "\u2517( T\uFE4FT )\u251B"]);
      }
    }
    return () => {
      const status = statusRef.value;
      const style = {
        width: formatLength(props.width),
        height: formatLength(props.height)
      };
      return vue.createVNode("div", {
        "class": preCls,
        "style": style
      }, [status !== "error" && getImg(), status === "loading" ? getPlaceholder() : status === "error" ? getError() : void 0]);
    };
  }
});

module.exports = Image;
