'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var useMemo = require('../_util/hooks/useMemo.js');
var utils = require('./utils.js');

const menuProps = {
  prefixCls: {
    default: "x-menu"
  },
  indent: {
    type: Number,
    default: 20
  },
  value: [String, Number],
  defaultExpandAll: Boolean,
  expandedKeys: Array,
  mode: {
    type: String,
    default: "inline"
  },
  options: {
    type: Array,
    default: () => []
  },
  collapsed: {
    type: Boolean,
    default: false
  },
  borderLight: {
    type: Boolean,
    default: true
  },
  disabled: Boolean,
  selectable: {
    default: true
  }
};
const MenuContextKey = Symbol("menu");
var Menu = vue.defineComponent({
  name: "x-menu",
  props: menuProps,
  emits: ["update:value", "update:expandedKeys", "expandChange", "select", "click"],
  setup(props, {
    emit
  }) {
    const expandedKeys = props.defaultExpandAll ? utils.getNonLeafKeys(props.options) : [];
    const expandedKeysRef = useMemo(() => props.expandedKeys || expandedKeys);
    const valueRef = useMemo(() => props.value);
    const activePathRef = vue.computed(() => utils.treeFindPath(props.options, ({
      value
    }) => value === valueRef.value));
    vue.watch(() => props.collapsed, () => [onExpandChange([])]);
    function onSelect(item) {
      emit("click", item);
      if (props.collapsed || props.mode === "horizontal" || props.mode === "vertical") {
        onExpandChange([]);
      }
      if (!props.selectable)
        return;
      const val = item.value;
      valueRef.value = val;
      emit("update:value", val);
      emit("select", item);
    }
    function onExpanded(item) {
      const val = item.value;
      const i = expandedKeysRef.value.findIndex((e) => e == val);
      if (~i) {
        expandedKeysRef.value.splice(i, 1);
      } else {
        expandedKeysRef.value.push(val);
      }
      onExpandChange(expandedKeysRef.value);
    }
    function onExpandChange(arr) {
      emit("update:expandedKeys", expandedKeysRef.value = arr);
      emit("expandChange", arr);
    }
    vue.provide(MenuContextKey, {
      props,
      valueRef,
      expandedKeysRef,
      activePathRef,
      collapsedRef: vue.computed(() => props.collapsed),
      onSelect,
      onExpanded
    });
    return () => {
      const {
        prefixCls
      } = props;
      const cls = {
        [prefixCls]: true,
        [`${prefixCls}-collapsed`]: props.collapsed,
        [`${prefixCls}-${props.mode}`]: true
      };
      return vue.createVNode("div", {
        "class": cls,
        "role": "menu"
      }, [props.options.map(utils.createItem)]);
    };
  }
});

exports.MenuContextKey = MenuContextKey;
exports["default"] = Menu;
