'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
require('../tooltip/index.js');
var MenuItemContent = require('./MenuItemContent.js');
var utils = require('./utils.js');
var Tooltip = require('../tooltip/Tooltip.js');

const menuItemProps = {
  label: [String, Object],
  value: [String, Number],
  icon: [Object, Function],
  disabled: Boolean
};
var MenuItem = vue.defineComponent({
  name: "x-menu-item",
  props: menuItemProps,
  setup(props) {
    const {
      paddingLeftRef,
      menuContext,
      disabledRef,
      isActiveRef,
      isRoot
    } = utils.useMenu(props);
    const prefixCls = "x-menu-item";
    const selectedRef = vue.computed(() => menuContext.valueRef.value === props.value);
    function onClick() {
      menuContext.onSelect(props);
    }
    return () => {
      const cls = {
        [prefixCls]: true,
        [`${prefixCls}-selected`]: selectedRef.value,
        [`${prefixCls}-disabled`]: disabledRef.value
      };
      return vue.createVNode(Tooltip, {
        "disabled": !isRoot || disabledRef.value || !menuContext.collapsedRef.value,
        "placement": "right",
        "title": props.label
      }, {
        default: () => [vue.createVNode("div", {
          "class": cls,
          "role": "menuitem",
          "aria-disabled": disabledRef.value
        }, [vue.createVNode(MenuItemContent, vue.mergeProps(props, {
          "style": `paddingLeft:${paddingLeftRef.value}px`,
          "active": isActiveRef.value,
          "onClick": onClick
        }), null)])]
      });
    };
  }
});

exports["default"] = MenuItem;
exports.menuItemProps = menuItemProps;
