'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var utils = require('./utils.js');
var _ = require('../_util/_.js');
require('../trigger/index.js');
var MenuItemContent = require('./MenuItemContent.js');
require('../expand-transition/index.js');
var expandTransition = require('../expand-transition/expand-transition.js');
var Trigger = require('../trigger/Trigger.js');

const submenuProps = {
  label: [String, Object],
  value: [String, Number],
  children: Array,
  icon: [Object, Function],
  disabled: Boolean
};
const SubmenuContextKey = Symbol("submenu");
var Submenu = vue.defineComponent({
  name: "x-submenu",
  props: submenuProps,
  setup(props) {
    const {
      paddingLeftRef,
      menuContext,
      horizontalRef,
      inlineRef,
      isActiveRef,
      disabledRef,
      isRoot
    } = utils.useMenu(props);
    const collapsedRef = vue.computed(() => !menuContext.expandedKeysRef.value.includes(props.value));
    function onClick() {
      if (disabledRef.value || menuContext.collapsedRef.value || !inlineRef.value)
        return;
      menuContext.onExpanded(props);
    }
    function onPopupVisibleChange(visible) {
      menuContext.onExpanded(props);
    }
    vue.provide(SubmenuContextKey, {
      props,
      paddingLeftRef
    });
    return () => {
      const prefixCls = "x-submenu";
      const horizontal = horizontalRef.value;
      const inline = inlineRef.value;
      const menuCollapsed = menuContext.collapsedRef.value;
      const collapsed = collapsedRef.value;
      const contentNode = vue.createVNode(MenuItemContent, vue.mergeProps(_.omit(props, "children"), {
        "showArrow": !menuCollapsed || !isRoot,
        "collapsed": collapsed,
        "style": `paddingLeft:${paddingLeftRef.value}px`,
        "active": isActiveRef.value,
        "onClick": onClick
      }), null);
      const childrenNode = vue.createVNode(expandTransition["default"], null, {
        default: () => [vue.withDirectives(vue.createVNode("div", {
          "class": `${prefixCls}_children`,
          "role": "menu"
        }, [props.children.map(utils.createItem)]), [[vue.vShow, !collapsed]])]
      });
      const popupNode = vue.createVNode("div", {
        "class": `${prefixCls}_children`,
        "role": "menu"
      }, [props.children.map(utils.createItem)]);
      return vue.createVNode(Trigger, {
        "prefixCls": prefixCls,
        "disabled": disabledRef.value || (!(horizontal || menuCollapsed) ? inline : false),
        "action": "hover",
        "popup": popupNode,
        "popupVisible": !collapsed,
        "onPopupVisibleChange": onPopupVisibleChange,
        "popupClass": `${prefixCls}-popup`,
        "popupPlacement": horizontal && isRoot ? "bottom" : "rightTop"
      }, {
        default: () => [vue.createVNode("div", {
          "class": prefixCls,
          "role": "menuitem",
          "aria-expanded": !collapsed,
          "aria-disabled": disabledRef.value
        }, [contentNode, !(menuCollapsed || horizontal || !inline) && childrenNode])]
      });
    };
  }
});

exports.SubmenuContextKey = SubmenuContextKey;
exports["default"] = Submenu;
exports.submenuProps = submenuProps;
