'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var Menu = require('./Menu.js');
var MenuItem = require('./MenuItem.js');
var MenuItemGroup = require('./MenuItemGroup.js');
var Submenu = require('./Submenu.js');

function useMenu(props) {
  const menuContext = vue.inject(Menu.MenuContextKey, void 0);
  const submenuContext = vue.inject(Submenu.SubmenuContextKey, void 0);
  const { props: menuProps } = menuContext;
  const isRoot = menuContext && !submenuContext;
  const horizontalRef = vue.computed(() => {
    return menuProps.mode === "horizontal";
  });
  const inlineRef = vue.computed(() => {
    return menuProps.mode === "inline";
  });
  const indentRef = vue.computed(() => {
    return horizontalRef.value ? 0 : menuProps.indent;
  });
  const parentPaddingLeftRef = vue.computed(() => {
    if (menuContext.collapsedRef.value)
      return 0;
    if (isRoot)
      return 0;
    if (submenuContext) {
      return submenuContext.paddingLeftRef.value;
    }
  });
  const paddingLeftRef = vue.computed(() => {
    if (horizontalRef.value)
      return void 0;
    if (!inlineRef.value)
      return void 0;
    return parentPaddingLeftRef.value + indentRef.value;
  });
  const disabledRef = vue.computed(() => {
    return menuContext.props.disabled || (submenuContext == null ? void 0 : submenuContext.props.disabled) || props.disabled;
  });
  const isActiveRef = vue.computed(() => {
    return menuContext.activePathRef.value.includes(props.value);
  });
  return {
    menuContext,
    submenuContext,
    horizontalRef,
    inlineRef,
    indentRef,
    parentPaddingLeftRef,
    paddingLeftRef,
    disabledRef,
    isActiveRef,
    isRoot
  };
}
function createItem(node) {
  if (node.children) {
    if (node.type === "group") {
      return vue.h(MenuItemGroup["default"], node);
    } else {
      return vue.h(Submenu["default"], node);
    }
  } else {
    return vue.h(MenuItem["default"], node);
  }
}
function traverseTree(tree, cb) {
  tree == null ? void 0 : tree.forEach((opt) => {
    if (opt.children)
      traverseTree(opt.children, cb);
    cb(opt);
  });
}
function getNonLeafKeys(tree) {
  const keys = [];
  traverseTree(tree, (opt) => keys.push(opt.value));
  return keys;
}
function treeFindPath(tree, func, path = []) {
  for (const item of tree) {
    path.push(item.value);
    if (func(item))
      return path;
    if (item.children) {
      const ret = treeFindPath(item.children, func, path);
      if (ret.length)
        return ret;
    }
    path.pop();
  }
  return [];
}

exports.createItem = createItem;
exports.getNonLeafKeys = getNonLeafKeys;
exports.traverseTree = traverseTree;
exports.treeFindPath = treeFindPath;
exports.useMenu = useMenu;
