'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var index = require('../_util/props-util/index.js');
var index$3 = require('../card/index.js');
var index$1 = require('../button/index.js');
var index$2 = require('../space/index.js');

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
const modalProps = {
  visible: Boolean,
  icon: Object,
  title: String,
  width: {
    default: 512
  },
  bodyStyle: [String, Object],
  bodyClass: String,
  to: {
    type: [String, Object],
    default: "body"
  },
  footer: Boolean,
  ok: {
    default: true
  },
  cancel: {
    default: true
  },
  mask: {
    default: true
  },
  maskClosable: {
    default: true
  },
  closable: {
    default: true
  },
  esc: {
    default: true
  },
  beforeOk: {
    type: Function
  }
};
const prefixCls = "x-modal";
var Modal = vue.defineComponent({
  name: prefixCls,
  inheritAttrs: false,
  props: modalProps,
  emits: ["update:visible", "change", "ok", "cancel", "afterLeave", "maskClick"],
  setup(props, {
    emit,
    slots,
    attrs
  }) {
    const loadingRef = vue.ref(false);
    const displayedRef = vue.ref(props.visible);
    vue.watch(vue.toRef(props, "visible"), (val) => {
      if (val)
        displayedRef.value = val;
    });
    function onAfterLeave() {
      displayedRef.value = false;
      emit("afterLeave");
    }
    const containerRef = vue.ref();
    vue.onMounted(() => {
      containerRef.value.addEventListener("scroll", (e) => {
        e.preventDefault();
        e.stopPropagation();
      });
    });
    function onKeydown(e) {
      if (e.key === "Escape" && props.esc)
        close();
    }
    vue.onMounted(() => {
      vue.watchPostEffect(() => {
        if (props.esc && props.visible)
          document.addEventListener("keydown", onKeydown);
        else
          document.removeEventListener("keydown", onKeydown);
      });
    });
    vue.onUnmounted(() => {
      document.removeEventListener("keydown", onKeydown);
    });
    function close() {
      emit("update:visible", false);
      emit("change", false);
    }
    function onMaskClick(e) {
      console.log("onMaskClick");
      emit("maskClick", e);
      if (!props.maskClosable)
        return;
      if (e.target === e.currentTarget)
        close();
    }
    function onOk() {
      if (props.beforeOk) {
        const ret = props.beforeOk();
        if (ret == null ? void 0 : ret.then) {
          loadingRef.value = true;
          ret.then(() => {
            loadingRef.value = false;
            close();
          });
        } else {
          if (ret !== false)
            close();
        }
      } else {
        close();
      }
      emit("ok");
    }
    function onCancel() {
      close();
      emit("cancel");
    }
    function getFooterNode() {
      if (slots.footer) {
        return slots.footer();
      } else if (props.footer) {
        const loading = loadingRef.value;
        const cancelProps = {
          class: `${prefixCls}_cancel`,
          onClick: onCancel
        };
        const okProps = {
          class: `${prefixCls}_ok`,
          loading,
          autofocus: true,
          onClick: onOk
        };
        let cancelBtn = slots.cancel ? index.getSlot(slots.cancel)[0] : props.cancel && vue.createVNode(index$1, null, {
          default: () => [vue.createTextVNode("\u53D6\u6D88")]
        });
        let okBtn = slots.ok ? index.getSlot(slots.ok)[0] : props.ok && vue.createVNode(index$1, {
          "type": "primary"
        }, {
          default: () => [vue.createTextVNode("\u786E\u8BA4")]
        });
        cancelBtn = cancelBtn ? vue.cloneVNode(cancelBtn, cancelProps) : void 0;
        okBtn = okBtn ? vue.cloneVNode(okBtn, okProps) : void 0;
        return vue.createVNode(index$2, {
          "justify": "end"
        }, {
          default: () => [cancelBtn, okBtn]
        });
      }
    }
    return (vm) => {
      const {
        to,
        visible,
        width,
        bodyStyle,
        bodyClass,
        closable
      } = props;
      const cardProps = __spreadProps(__spreadValues({}, attrs), {
        class: prefixCls,
        style: {
          width: width + "px"
        },
        closable,
        contentStyle: bodyStyle,
        contentClass: [`${prefixCls}_body`, bodyClass],
        footerClass: `${prefixCls}_footer`,
        role: "document",
        onClose: onCancel
      });
      return vue.createVNode(vue.Teleport, {
        "to": to
      }, {
        default: () => [vue.withDirectives(vue.createVNode("div", {
          "class": `${prefixCls}-container`,
          "ref": containerRef
        }, [vue.createVNode(vue.Transition, {
          "name": "fade",
          "appear": true
        }, {
          default: () => [vue.withDirectives(vue.createVNode("div", {
            "class": [`${prefixCls}-mask`, props.mask && "show"],
            "onClick": onMaskClick
          }, null), [[vue.vShow, props.visible]])]
        }), vue.createVNode(vue.Transition, {
          "name": prefixCls,
          "appear": true,
          "onAfterLeave": onAfterLeave
        }, {
          default: () => [vue.withDirectives(vue.createVNode(index$3, cardProps, {
            icon: () => index.getComponent(vm, "icon"),
            title: () => index.getComponent(vm, "title"),
            default: slots.default,
            footer: getFooterNode
          }), [[vue.vShow, visible]])]
        })]), [[vue.vShow, displayedRef.value]])]
      });
    };
  }
});

exports["default"] = Modal;
exports.prefixCls = prefixCls;
