'use strict';

var vue = require('vue');
var index = require('../../tag/index.js');

var Selector = vue.defineComponent({
  name: "Selector",
  props: {
    prefixCls: String,
    values: Array,
    searchValue: String,
    multiple: Boolean,
    showArrow: Boolean,
    filterable: Boolean,
    clearable: Boolean,
    disabled: Boolean,
    placeholder: String,
    inputRef: {
      default: () => vue.ref()
    },
    onSelect: Function,
    onSearch: Function,
    onToggleOpen: Function,
    onFocus: Function,
    onBlur: Function
  },
  setup(props) {
    function onSelect(item) {
      var _a;
      (_a = props.onSelect) == null ? void 0 : _a.call(props, item);
    }
    function onClick() {
      props.inputRef.value.focus();
    }
    function onMousedown() {
      props.onToggleOpen();
    }
    function onInputChange(e) {
      props.onToggleOpen(true);
      props.onSearch(e.target.value);
    }
    return () => {
      var _a;
      const {
        prefixCls,
        values,
        multiple
      } = props;
      const inputProps = {
        ref: props.inputRef,
        class: `${prefixCls}_search_input`,
        value: props.searchValue,
        disabled: props.disabled || !props.filterable && !props.multiple,
        placeholder: !values.length ? props.placeholder : void 0,
        onInput: onInputChange,
        onFocus: props.onFocus,
        onBlur: props.onBlur
      };
      const tagsNode = multiple ? values.map((e) => vue.createVNode(index, {
        "class": `${prefixCls}_tag`,
        "closable": !props.disabled,
        "onClose": () => onSelect(e)
      }, {
        default: () => [e == null ? void 0 : e.label]
      })) : void 0;
      const textNode = vue.createVNode("span", {
        "class": `${prefixCls}_text`
      }, [!multiple && !props.searchValue ? (_a = values[0]) == null ? void 0 : _a.label : " "]);
      return vue.createVNode("div", {
        "class": `${prefixCls}_selector`,
        "onClick": onClick,
        "onMousedown": onMousedown
      }, [tagsNode, vue.createVNode("div", {
        "class": `${prefixCls}_search`
      }, [vue.createVNode("input", inputProps, null)]), textNode]);
    };
  }
});

module.exports = Selector;
