'use strict';

var vue = require('vue');
var _interface = require('./interface.js');
var resizeobserver = require('../_util/Dom/resizeobserver.js');
var skeleton = require('./skeleton.js');

const SkeletonItem = {
  mounted(el, binding) {
    const props = skeleton.skeletonList.findLast((e) => e.el.contains(el));
    if (!props)
      return;
    const child = createItem(props, el, binding);
    props.targets.push(child);
  },
  beforeUnmount(el) {
    const props = skeleton.skeletonList.findLast((e) => e.el.contains(el));
    if (!props)
      return;
    const i = props.targets.findIndex((e) => e.el === el);
    if (i < 0)
      return;
    const child = props.targets[i];
    props.targets.splice(i, 1);
    resizeobserver.dispose(props.el, child.resizeCb);
  }
};
const createItem = (props, el, binding) => {
  el.classList.add(`${_interface.itemPreCls}-ref`);
  const { el: parentEl } = props;
  const child = {
    el,
    binding,
    state: vue.reactive({}),
    resizeCb: () => {
      const parentRect = parentEl.getBoundingClientRect(), parentStyle = getComputedStyle(parentEl);
      const style = getComputedStyle(el), rect = el.getBoundingClientRect();
      const _style = { position: "absolute" };
      ["top", "left"].forEach((e) => {
        const borderWidth = parseInt(parentStyle[vue.camelize(`border-${e}-width`)]);
        _style[e] = Math.abs(rect[e] - parentRect[e]) - borderWidth + "px";
      });
      ["width", "height"].forEach((e) => _style[e] = Math.ceil(rect[e]) + "px");
      _style.borderRadius = style.borderRadius;
      _style.zIndex = +style.zIndex + 1;
      child.state.style = _style;
    }
  };
  child.resizeCb();
  resizeobserver.observer(parentEl, child.resizeCb);
  return child;
};

module.exports = SkeletonItem;
