'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var _interface = require('./interface.js');

const patchClass = (el, clazz, oldClazz) => {
  clazz = clazz.split(" "), oldClazz = oldClazz.split(" ");
  const delCls = oldClazz.filter((e) => !clazz.includes(e)), addCls = clazz;
  delCls.forEach((e) => e && el.classList.remove(e));
  addCls.forEach((e) => e && el.classList.add(e));
};
const getLoading = (binding) => typeof binding.value === "object" ? binding.value.loading : binding.value;
const getAnimated = (binding) => binding.modifiers.animated;
const getClass = (binding) => {
  const loading = getLoading(binding);
  if (!loading)
    return "";
  const animated = getAnimated(binding);
  return vue.normalizeClass([_interface.preCls, { [`${_interface.preCls}-animated`]: animated }, binding.value.loadingClass]);
};
const allClass = (binding) => {
  return vue.normalizeClass([_interface.preCls, `${_interface.preCls}-animated`, binding.value.loadingClass]);
};
const fliterClass = (cls) => {
  return cls.split(" ").filter((cls2) => cls2.includes(_interface.preCls)).join(" ");
};
function mergeProps(vnode, binding) {
  if (getLoading(binding)) {
    if (vnode.props) {
      const props = vue.mergeProps(vnode.props, {
        class: getClass(binding)
      });
      props.class = [...new Set(props.class.split(" "))].join(" ");
      Object.assign(vnode.props, props);
    } else {
      const clazz = vue.normalizeClass([vnode.el.className, getClass(binding)]);
      vnode.el.className = clazz;
    }
  }
}

exports.allClass = allClass;
exports.fliterClass = fliterClass;
exports.getAnimated = getAnimated;
exports.getClass = getClass;
exports.getLoading = getLoading;
exports.mergeProps = mergeProps;
exports.patchClass = patchClass;
