'use strict';

var vue = require('vue');
var shared = require('@vue/shared');
var core = require('@vueuse/core');
var index = require('../_internal/display-directive/index.js');
var _interface = require('./interface.js');
var utils = require('./utils.js');

const preCls = "x-tab-pane";
const tabPaneProps = {
  label: [String, Number],
  name: [String, Number],
  displayDirective: String
};
var TabPane = vue.defineComponent({
  name: preCls,
  props: tabPaneProps,
  setup(props, {
    slots
  }) {
    const proxy = vue.getCurrentInstance().proxy;
    const tabsContext = vue.inject(_interface.TabsContextKey);
    tabsContext.tabpanes.value.push(proxy);
    vue.onBeforeUnmount(() => shared.remove(tabsContext.tabpanes.value, proxy));
    const key = vue.computed(() => {
      var _a;
      return (_a = utils.getKey(proxy)) != null ? _a : tabsContext.tabpanes.value.indexOf(proxy);
    });
    const visible = core.computedEager(() => key.value == tabsContext.value.value);
    return () => vue.createVNode(index, {
      "type": props.displayDirective,
      "visible": visible.value && !!slots.default
    }, {
      default: () => {
        var _a;
        return [vue.createVNode("div", {
          "class": preCls
        }, [(_a = slots.default) == null ? void 0 : _a.call(slots)])];
      }
    });
  }
});

module.exports = TabPane;
