'use strict';

var vue = require('vue');
var index = require('../sunken/index.js');
var index$1 = require('../_util/props-util/index.js');
require('../icon/index.js');
var Icon = require('../icon/Icon.js');

const prefixCls = "x-tag";
const Tag = vue.defineComponent({
  name: prefixCls,
  props: {
    closable: Boolean,
    closeIcon: [String, Object],
    color: String,
    icon: Object,
    round: Boolean,
    bordered: Boolean,
    nowrap: Boolean,
    size: {
      type: String,
      default: "small"
    },
    type: {
      type: String,
      default: "default"
    },
    onClose: Function
  },
  emits: ["close"],
  directives: {
    [index.name]: index
  },
  setup(props, {
    slots,
    emit
  }) {
    function onClose(e) {
      e.stopPropagation();
      emit("close", e);
    }
    function onMousedown(e) {
      e.stopPropagation();
    }
    function renderCloseNode(vm) {
      let cls = `${prefixCls}-close-icon`;
      if (props.closable) {
        let node, icon = props.closeIcon || "cross";
        if (typeof icon === "string") {
          node = vue.createVNode(Icon["default"], {
            "class": cls,
            "type": icon
          }, null);
        } else {
          node = vue.createVNode("div", {
            "class": cls
          }, [index$1.getComponent(vm, "closeIcon")]);
        }
        node.props.onClick = onClose;
        node.props.onMousedown = onMousedown;
        return node;
      }
    }
    return (vm) => {
      var _a;
      const {
        color,
        size,
        type
      } = props;
      const style = {
        backgroundColor: color
      };
      const cls = [prefixCls, `${prefixCls}-${size}`, `${prefixCls}-${type}`, {
        [`${prefixCls}-round`]: props.round,
        [`${prefixCls}-bordered`]: props.bordered,
        [`${prefixCls}-nowrap`]: props.nowrap
      }];
      const iconNode = index$1.render(props.icon);
      return vue.withDirectives(vue.createVNode("span", {
        "class": cls,
        "style": style
      }, [iconNode, (_a = slots.default) == null ? void 0 : _a.call(slots), renderCloseNode(vm)]), [[vue.resolveDirective("sunken")]]);
    };
  }
});
Tag.install = (app) => {
  app.component(Tag.name, Tag);
};

module.exports = Tag;
