'use strict';

var vue = require('vue');
var shared = require('@vue/shared');
var index = require('../_util/props-util/index.js');
require('../trigger/index.js');
var placements = require('./placements.js');
var tooltipProps = require('./tooltipProps.js');
var Trigger = require('../trigger/Trigger.js');

var Tooltip = vue.defineComponent({
  name: "x-tooltip",
  props: tooltipProps,
  slots: ["title"],
  emits: ["update:visible", "visibleChange"],
  setup(props, {
    emit,
    slots
  }) {
    const {
      proxy: vm
    } = vue.getCurrentInstance();
    const {
      prefixCls,
      builtinPlacements
    } = props;
    const state = vue.reactive({
      visible: props.visible
    });
    vue.watch(() => props.visible, (v) => {
      state.visible = v;
    });
    function onPopupVisibleChange(v) {
      state.visible = v;
      emit("update:visible", v);
      emit("visibleChange", v);
    }
    function getPopupElement() {
      return index.getComponent(vm, "title");
    }
    return () => {
      const popupClass = shared.normalizeClass([`${prefixCls} ${prefixCls}-placement-${props.placement}`, props.popupClass]);
      const triggerProps = {
        action: props.trigger,
        disabled: props.disabled,
        popup: getPopupElement(),
        popupClass,
        popupTransitionName: props.transitionName || prefixCls,
        popupAlign: props.align || (builtinPlacements == null ? void 0 : builtinPlacements[props.placement]) || placements.placements[props.placement],
        getPopupContainer: props.getPopupContainer,
        onPopupVisibleChange,
        mouseEnterDelay: props.mouseEnterDelay,
        mouseLeaveDelay: props.mouseLeaveDelay,
        popupStyle: props.popupStyle
      };
      return vue.createVNode(Trigger, triggerProps, {
        default: () => {
          var _a;
          return [(_a = slots.default) == null ? void 0 : _a.call(slots)];
        }
      });
    };
  }
});

module.exports = Tooltip;
