'use strict';

var vue = require('vue');
require('../_util/css/index.js');
var index = require('../_util/props-util/index.js');
require('../_util/hooks/index.js');
var index$1 = require('../drag-resize/index.js');
require('../icon/index.js');
var useMergedState = require('../_util/hooks/useMergedState.js');
var formatLength = require('../_util/css/format-length.js');
var Icon = require('../icon/Icon.js');

const windowProps = {
  title: [String, Object],
  prefix: [String, Object],
  suffix: [String, Object],
  draggable: {
    type: Boolean,
    default: true
  },
  closable: {
    type: Boolean,
    default: true
  },
  fullscreen: {
    type: Boolean,
    default: void 0
  },
  resizable: {
    type: Boolean,
    default: true
  },
  w: Number,
  h: Number,
  type: {
    type: String,
    default: "default"
  },
  headerStyle: [String, Array, Object],
  bodyStyle: [String, Array, Object],
  footer: [Function, Object, Array]
};
const prefixCls = "x-window";
var Window = vue.defineComponent({
  name: prefixCls,
  props: windowProps,
  // prettier-ignore
  emits: ["close", "resize", "dragging", "resizing", "update:width", "update:height", "update:x", "update:y", "update:w", "update:h", "update:fullscreen", "resizing", "resize-start", "resize-end", "activated", "deactivated"],
  setup(props, {
    emit,
    slots
  }) {
    const elRef = vue.ref();
    const headerRef = vue.ref();
    vue.onMounted(() => {
      index.getEL(elRef.value).addEventListener("mousedown", (e) => index.getEL(elRef.value).focus());
    });
    const mergeFullscreen = useMergedState(vue.toRef(props, "fullscreen"), vue.ref(false), (val) => emit("update:fullscreen", val));
    const styleRef = vue.computed(() => {
      return mergeFullscreen.value ? `` : `width: ${formatLength(props.h)}; height: ${formatLength(props.w)}`;
    });
    let lastStyle = "";
    let style = "";
    function onToggleSize() {
      if (!props.resizable)
        return;
      if (!mergeFullscreen.value) {
        lastStyle = index.getEL(elRef.value).getAttribute("style");
      } else {
        style = lastStyle;
        vue.nextTick(() => style = "");
      }
      mergeFullscreen.value = !mergeFullscreen.value;
    }
    function onClose() {
      emit("close");
    }
    function prevent(e) {
      e.stopPropagation();
    }
    return (vm) => {
      return vue.createVNode(index$1["default"], {
        "class": [prefixCls, `${prefixCls}-${props.type}`, {
          [`${prefixCls}-resizable`]: props.resizable,
          [`${prefixCls}-fullscreen`]: mergeFullscreen.value
        }],
        "style": style,
        "ref": elRef,
        "dragTarget": headerRef,
        "type": "simple",
        "tabindex": "0"
      }, {
        default: () => {
          var _a;
          return [vue.createVNode("div", {
            "class": `${prefixCls}_header`,
            "style": props.headerStyle,
            "ref": headerRef
          }, [index.getComponent(vm, "prefix"), vue.createVNode("div", {
            "class": `${prefixCls}_title`
          }, [index.getComponent(vm, "title")]), vue.createVNode("div", {
            "class": `${prefixCls}_suffix`
          }, [index.getComponent(vm, "suffix")]), props.resizable && vue.createVNode(Icon["default"], {
            "class": `${prefixCls}_operation`,
            "type": "Rectangle",
            "onMousedown": prevent,
            "onClick": onToggleSize
          }, null), props.closable && vue.createVNode(Icon["default"], {
            "class": `${prefixCls}_operation ${prefixCls}_close`,
            "type": "cross",
            "onMousedown": prevent,
            "onClick": onClose
          }, null)]), vue.createVNode("div", {
            "class": `${prefixCls}_body`,
            "style": props.bodyStyle
          }, [(_a = slots.default) == null ? void 0 : _a.call(slots)]), index._cloneVNode(index.getComponent(vm, "footer"), {
            class: `${prefixCls}_footer`
          })];
        }
      });
    };
  }
});

module.exports = Window;
