import { defineComponent, onMounted, onBeforeUnmount, cloneVNode } from 'vue';
import { render } from '../_util/props-util/index.js';

const messageProps = {
  prefixCls: String,
  default: [Object, Function],
  duration: {
    default: 3e3
  },
  key: [String, Number]
};
var Message = defineComponent({
  props: messageProps,
  emits: ["close"],
  setup(props, {
    emit
  }) {
    let timer;
    function clearTimer() {
      clearTimeout(timer);
    }
    function retimer() {
      clearTimeout(timer);
      const {
        duration
      } = props;
      if (duration) {
        timer = setTimeout(close, duration);
      }
    }
    function close() {
      emit("close");
    }
    onMounted(() => {
      retimer();
    });
    onBeforeUnmount(() => {
      clearTimer();
    });
    return () => cloneVNode(render(props.default), {
      onMouseenter: clearTimer,
      onMouseleave: retimer
    });
  }
});

export { Message as default };
