var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
function castArray(val) {
  return Array.isArray(val) ? val : val == null ? [] : [val];
}
function get(obj, path) {
  if (!obj)
    return obj;
  if (!path)
    return void 0;
  if (typeof path === "string")
    path = path.split(".");
  for (let i = 0, len = path.length; i < len; i++) {
    if ((obj = obj[path[i]]) == null)
      break;
  }
  return obj;
}
function set(obj, path, val) {
  var _a;
  if (!obj)
    return obj;
  if (!path)
    return obj;
  if (typeof path === "string")
    path = path.split(".");
  let temp = obj;
  for (var i = 0, len = path.length - 1; i < len; i++) {
    temp = (_a = temp[path[i]]) != null ? _a : temp[path[i]] = {};
  }
  temp[path[i]] = val;
  return obj;
}
function property(path) {
  return (obj) => get(obj, path);
}
function keyBy(arr, iteratee) {
  if (typeof iteratee !== "function")
    iteratee = property(iteratee);
  return arr.reduce((obj, item) => (obj[iteratee(item)] = item, obj), {});
}
function omit(obj, path) {
  path = castArray(path);
  const temp = __spreadValues({}, obj);
  path.forEach((key) => {
    delete temp[key];
  });
  return temp;
}
function cloneDeep(obj) {
  if (obj == null)
    return obj;
  if (obj instanceof Date)
    return new Date(obj);
  if (obj instanceof RegExp)
    return new RegExp(obj);
  if (typeof obj !== "object")
    return obj;
  let cloneObj = new obj.constructor();
  for (const key in obj) {
    if (obj.hasOwnProperty(key)) {
      cloneObj[key] = cloneDeep(obj[key]);
    }
  }
  return cloneObj;
}
function throttle(fn, wait) {
  let t1, t2, args = [], timer;
  const fun = (..._args) => {
    args = _args;
    t1 = Date.now();
    if (t1 >= t2 + wait) {
      fn.apply(null, args);
      t2 = t1;
    } else {
      if (timer)
        return;
      timer = setTimeout(() => {
        fn.apply(null, args);
        t2 = Date.now();
        timer = null;
      }, t2 + wait - t1);
    }
  };
  fun.cancel = () => {
    clearTimeout(timer);
    timer = null;
  };
  return fun;
}

export { castArray, cloneDeep, get, keyBy, omit, property, set, throttle };
