import { defineComponent, ref, unref, onUpdated, onMounted, onUnmounted, cloneVNode } from 'vue';
import alignElement, { alignPoint } from '../_util/dom-align/index.js';
import { findDOMNode } from '../_util/props-util/index.js';
import { isSamePoint, monitorResize } from './util.js';
import { unrefElement } from '@vueuse/core';

const alignProps = {
  align: Object,
  target: [Object, Function],
  onAlign: Function,
  disabled: [Boolean, Object],
  resizeObservable: {
    type: [Boolean, Object],
    default: true
  }
};
function getElement(ins) {
  const el = unrefElement(ins);
  return el instanceof HTMLElement ? el : void 0;
}
function getPoint(point) {
  const el = unrefElement(point);
  if (el instanceof HTMLElement) {
    const {
      offsetLeft: pageX,
      offsetTop: pageY
    } = getElement(point);
    return {
      pageX,
      pageY
    };
  } else {
    return point;
  }
}
var Align = defineComponent({
  name: "Align",
  props: alignProps,
  setup(props, {
    slots,
    expose
  }) {
    const sourceRef = ref();
    function forceAlign() {
      if (unref(props.disabled))
        return;
      const {
        onAlign,
        align
      } = props;
      const source = findDOMNode(sourceRef.value);
      if (props.target && source) {
        let result;
        const target = getElement(props.target), point = getPoint(props.target);
        targetResizeMonitor.el = target;
        targetResizeMonitor.point = point;
        if (target) {
          result = alignElement(source, target, unref(align));
        } else if (point) {
          result = alignPoint(source, point, unref(align));
        }
        if (onAlign && result) {
          onAlign(source, result);
        }
      }
    }
    const targetResizeMonitor = {
      el: null,
      point: null,
      cancel: () => {
      }
    };
    const sourceResizeMonitor = {
      el: null,
      cancel: () => {
      }
    };
    function goAlign() {
      if (unref(props.disabled))
        return;
      const source = findDOMNode(sourceRef.value);
      if (source !== sourceResizeMonitor.el) {
        sourceResizeMonitor.cancel();
        sourceResizeMonitor.el = source;
      }
      const target = getElement(props.target), point = getPoint(props.target);
      if (targetResizeMonitor.el != target || !isSamePoint(targetResizeMonitor.point, point)) {
        forceAlign();
        if (targetResizeMonitor.el != target) {
          targetResizeMonitor.cancel();
          targetResizeMonitor.el = target;
          targetResizeMonitor.point = point;
          targetResizeMonitor.cancel = monitorResize(target, forceAlign);
        }
      }
    }
    onUpdated(() => {
      goAlign();
    });
    onMounted(() => {
      goAlign();
    });
    onUnmounted(() => {
      targetResizeMonitor.cancel();
      sourceResizeMonitor.cancel();
    });
    expose({
      forceAlign
    });
    return () => {
      var _a;
      const child = (_a = slots.default) == null ? void 0 : _a.call(slots);
      if (child) {
        return cloneVNode(child[0], {
          ref: sourceRef
        }, true);
      }
    };
  }
});

export { Align as default };
