import { defineComponent, ref, inject, reactive, toRef, provide, onBeforeUnmount } from 'vue';
import { remove } from '@vue/shared';
import { computedEager } from '@vueuse/core';
import useNamespace from '../_util/hooks/useNameSpace2.js';
import { AnchorContextKey, AnchorLiinkContextKey } from './context.js';

const preCls = "x-anchor-link";
var _sfc_main = defineComponent({
  name: preCls,
  props: {
    href: String,
    title: String
  },
  setup(props) {
    const ns = useNamespace(preCls);
    const linkRef = ref();
    const anchorContext = inject(AnchorContextKey);
    const anchorLiinkContext = inject(AnchorLiinkContextKey, void 0);
    const indent = (anchorLiinkContext == null ? void 0 : anchorLiinkContext.indent) ? (anchorLiinkContext == null ? void 0 : anchorLiinkContext.indent) + 1 : 1;
    const isActive = computedEager(() => anchorContext.value.value == props.href);
    const state = reactive({
      el: linkRef,
      href: toRef(props, "href"),
      indent
    });
    provide(AnchorLiinkContextKey, state);
    anchorContext.links.push(state);
    onBeforeUnmount(() => {
      remove(anchorContext.links, state);
    });
    function onClick() {
      anchorContext.setActive(props.href);
    }
    return {
      ns,
      linkRef,
      indent,
      style: `padding-left: ${indent * 16}px`,
      isActive,
      onClick
    };
  }
});

export { _sfc_main as default };
