import { defineComponent, ref, computed, onMounted, watch, toRef, createVNode } from 'vue';
import hljs from 'highlight.js/lib/core';
import xml from 'highlight.js/lib/languages/xml';
import javascript from 'highlight.js/lib/languages/javascript';
import 'highlight.js/styles/atom-one-dark.css';

hljs.registerLanguage("javascript", javascript);
hljs.registerLanguage("html", xml);
const prefixCls = "x-code";
const Code = defineComponent({
  name: prefixCls,
  props: {
    code: String,
    language: String,
    trim: {
      default: true
    }
  },
  setup(props, {
    slots
  }) {
    const codeRef = ref();
    const resultRef = computed(() => {
      let code = props.code;
      if (!code)
        return {};
      if (props.trim)
        code = code.trim();
      if (props.language) {
        return hljs.highlight(code, {
          language: props.language,
          ignoreIllegals: true
        });
      } else {
        return hljs.highlightAuto(code);
      }
    });
    const languageRef = computed(() => resultRef.value.language || props.language);
    function setCode() {
      if (slots.default)
        return;
      if (!codeRef.value)
        return;
      codeRef.value.innerHTML = resultRef.value.value;
    }
    onMounted(setCode);
    watch([toRef(props, "code"), toRef(props, "language")], setCode);
    return () => {
      var _a;
      const cls = [prefixCls];
      const language = languageRef.value;
      return createVNode("code", {
        "class": ["hljs " + language, cls]
      }, [slots.default ? (_a = slots.default) == null ? void 0 : _a.call(slots) : createVNode("pre", {
        "ref": codeRef
      }, null)]);
    };
  }
});
Code.install = (app) => {
  app.component(Code.name, Code);
};

export { Code as default };
