import { isVNode, defineComponent, getCurrentInstance, ref, onMounted, computed, cloneVNode, createVNode, withDirectives, vShow, Teleport, mergeProps, Transition } from 'vue';
import { getComponent, getSlot } from '../_util/props-util/index.js';

function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const preCls = "x-drawer";
const Drawer = defineComponent({
  name: preCls,
  props: {
    title: String,
    visible: Boolean,
    width: {
      type: [Number, String],
      default: 396
    },
    mask: {
      type: Boolean,
      default: true
    },
    maskClosable: {
      type: Boolean,
      default: true
    },
    to: {
      type: [String, Object],
      default: "body"
    }
  },
  inheritAttrs: false,
  emits: ["update:visible"],
  setup(props, {
    attrs,
    emit
  }) {
    const {
      proxy: vm
    } = getCurrentInstance();
    function onClose() {
      setVisible(false);
    }
    function onMaskClick() {
      if (!props.maskClosable)
        return;
      onClose();
    }
    function setVisible(visible) {
      emit("update:visible", visible);
    }
    const isMounted = ref(false);
    onMounted(() => {
      isMounted.value = true;
    });
    const headerRef = computed(() => {
      var _a;
      let title = getComponent(vm, "title");
      let header = (_a = getComponent(vm, "header")) == null ? void 0 : _a[0];
      if (!header && !title)
        return void 0;
      const extraProps = {
        class: `${preCls}_header`
      };
      if (header) {
        header = cloneVNode(header, extraProps);
      } else {
        header = createVNode("div", extraProps, [createVNode("div", {
          "class": `${preCls}_title`
        }, [title])]);
      }
      return header;
    });
    const footerRef = computed(() => {
      const footer = getComponent(vm, "footer");
      if (!footer)
        return void 0;
      return createVNode("div", {
        "class": `${preCls}_footer`
      }, [footer]);
    });
    return () => {
      if (!isMounted.value)
        return;
      const {
        mask: hasMask,
        to,
        visible,
        width
      } = props;
      const body = createVNode("div", {
        "class": `${preCls}_body`
      }, [getSlot(vm)]);
      const mask = hasMask ? withDirectives(createVNode("div", {
        "class": `${preCls}_mask`,
        "onClick": onMaskClick
      }, null), [[vShow, visible]]) : void 0;
      const clazz = [preCls, {
        [`${preCls}-open`]: visible,
        [`${preCls}-glass`]: visible
      }];
      return createVNode(Teleport, {
        "to": to
      }, {
        default: () => [createVNode("div", mergeProps({
          "class": clazz
        }, attrs), [createVNode(Transition, {
          "name": "fade"
        }, _isSlot(mask) ? mask : {
          default: () => [mask]
        }), createVNode("div", {
          "class": `${preCls}_wrapper`,
          "style": {
            width: width + "px"
          }
        }, [headerRef.value, body, footerRef.value])])]
      });
    };
  }
});
Drawer.install = (app) => {
  app.component(Drawer.name, Drawer);
};

export { Drawer as default };
