import { defineComponent, createVNode } from 'vue';
import '../_util/css/index.js';
import create from './IconFont.js';
import formatLength from '../_util/css/format-length.js';

const MyIconFont = create({
  scriptUrl: "//at.alicdn.com/t/c/font_2698224_awmh8fka824.js"
});
const iconProps = {
  type: String,
  spin: Boolean,
  color: String,
  size: [String, Number]
};
const Icon = defineComponent({
  name: "x-icon",
  props: iconProps,
  emits: ["click"],
  setup(props, {
    emit
  }) {
    function onClick(e) {
      emit("click", e);
    }
    return () => {
      const {
        spin
      } = props, prefixCls = "x-icon";
      const cls = [prefixCls, {
        [`${prefixCls}-spin`]: spin
      }];
      const style = {
        fontSize: formatLength(props.size),
        color: props.color
      };
      return createVNode(MyIconFont, {
        "class": cls,
        "style": style,
        "type": props.type,
        "onClick": onClick
      }, null);
    };
  }
});
Icon.install = (app) => {
  app.component(Icon.name, Icon);
};

export { Icon as default, iconProps };
