import { defineComponent, getCurrentInstance, reactive, watch, createVNode, mergeProps } from 'vue';
import { getComponent } from '../_util/props-util/index.js';
import Star from './Star.js';
import '../icon/index.js';
import Icon from '../icon/Icon.js';

const Rate = defineComponent({
  name: "x-rate",
  props: {
    prefixCls: {
      default: "x-rate"
    },
    value: Number,
    character: String,
    count: {
      default: 5
    },
    color: String,
    allowHalf: Boolean,
    disabled: Boolean
  },
  emits: ["update:value", "change", "hoverChange"],
  setup(props, {
    emit
  }) {
    const {
      proxy: self
    } = getCurrentInstance();
    const state = reactive({
      value: props.value,
      hoverValue: null
    });
    watch(() => props.value, (val) => {
      state.value = val;
    });
    function getStarValue(e, i) {
      if (props.allowHalf) {
        return e.offsetX > e.target.offsetWidth / 2 ? i + 1 : i + 0.5;
      } else {
        return i + 1;
      }
    }
    function onClick(e, i) {
      state.value = getStarValue(e, i);
    }
    function onHover(e, i) {
      state.hoverValue = getStarValue(e, i);
      emit("hoverChange", state.hoverValue);
    }
    function onMouseleave() {
      state.hoverValue = null;
    }
    return () => {
      const {
        prefixCls,
        disabled
      } = props;
      const ratePorps = {
        class: prefixCls,
        role: "radiogroup",
        tabindex: 0,
        onMouseleave: disabled ? null : onMouseleave
      };
      const itemProps = {
        prefixCls: `${prefixCls}_star`,
        value: state.hoverValue || state.value,
        character: getComponent(self, "character") || createVNode(Icon, {
          "type": "ziyuan"
        }, null),
        allowHalf: props.allowHalf,
        disabled: props.disabled,
        count: props.count,
        color: props.color,
        onClick,
        onHover
      };
      const children = Array.from(Array(props.count), (_, i) => {
        return createVNode(Star, mergeProps(itemProps, {
          "index": i
        }), null);
      });
      return createVNode("div", ratePorps, [children]);
    };
  }
});
Rate.install = (app) => {
  app.component(Rate.name, Rate);
};

export { Rate as default };
