import { reactive, camelize } from 'vue';
import { itemPreCls } from './interface.js';
import resizeobserver from '../_util/Dom/resizeobserver.js';
import { skeletonList } from './skeleton.js';

const SkeletonItem = {
  mounted(el, binding) {
    const props = skeletonList.findLast((e) => e.el.contains(el));
    if (!props)
      return;
    const child = createItem(props, el, binding);
    props.targets.push(child);
  },
  beforeUnmount(el) {
    const props = skeletonList.findLast((e) => e.el.contains(el));
    if (!props)
      return;
    const i = props.targets.findIndex((e) => e.el === el);
    if (i < 0)
      return;
    const child = props.targets[i];
    props.targets.splice(i, 1);
    resizeobserver.dispose(props.el, child.resizeCb);
  }
};
const createItem = (props, el, binding) => {
  el.classList.add(`${itemPreCls}-ref`);
  const { el: parentEl } = props;
  const child = {
    el,
    binding,
    state: reactive({}),
    resizeCb: () => {
      const parentRect = parentEl.getBoundingClientRect(), parentStyle = getComputedStyle(parentEl);
      const style = getComputedStyle(el), rect = el.getBoundingClientRect();
      const _style = { position: "absolute" };
      ["top", "left"].forEach((e) => {
        const borderWidth = parseInt(parentStyle[camelize(`border-${e}-width`)]);
        _style[e] = Math.abs(rect[e] - parentRect[e]) - borderWidth + "px";
      });
      ["width", "height"].forEach((e) => _style[e] = Math.ceil(rect[e]) + "px");
      _style.borderRadius = style.borderRadius;
      _style.zIndex = +style.zIndex + 1;
      child.state.style = _style;
    }
  };
  child.resizeCb();
  resizeobserver.observer(parentEl, child.resizeCb);
  return child;
};

export { SkeletonItem as default };
