import { normalizeClass, mergeProps as mergeProps$1 } from 'vue';
import { preCls } from './interface.js';

const patchClass = (el, clazz, oldClazz) => {
  clazz = clazz.split(" "), oldClazz = oldClazz.split(" ");
  const delCls = oldClazz.filter((e) => !clazz.includes(e)), addCls = clazz;
  delCls.forEach((e) => e && el.classList.remove(e));
  addCls.forEach((e) => e && el.classList.add(e));
};
const getLoading = (binding) => typeof binding.value === "object" ? binding.value.loading : binding.value;
const getAnimated = (binding) => binding.modifiers.animated;
const getClass = (binding) => {
  const loading = getLoading(binding);
  if (!loading)
    return "";
  const animated = getAnimated(binding);
  return normalizeClass([preCls, { [`${preCls}-animated`]: animated }, binding.value.loadingClass]);
};
const allClass = (binding) => {
  return normalizeClass([preCls, `${preCls}-animated`, binding.value.loadingClass]);
};
const fliterClass = (cls) => {
  return cls.split(" ").filter((cls2) => cls2.includes(preCls)).join(" ");
};
function mergeProps(vnode, binding) {
  if (getLoading(binding)) {
    if (vnode.props) {
      const props = mergeProps$1(vnode.props, {
        class: getClass(binding)
      });
      props.class = [...new Set(props.class.split(" "))].join(" ");
      Object.assign(vnode.props, props);
    } else {
      const clazz = normalizeClass([vnode.el.className, getClass(binding)]);
      vnode.el.className = clazz;
    }
  }
}

export { allClass, fliterClass, getAnimated, getClass, getLoading, mergeProps, patchClass };
