import { defineComponent, getCurrentInstance, ref, computed, onMounted, onBeforeUnmount, createVNode } from 'vue';
import addEventListenerWrap from '../_util/Dom/addEventListener.js';
import '../tooltip/index.js';
import Tooltip from '../tooltip/Tooltip.js';

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var Hanlde = defineComponent({
  props: {
    prefixCls: String,
    value: Number,
    disabled: Boolean,
    min: Number,
    max: Number,
    formatTooltip: Function,
    tooltip: Boolean,
    onMousedown: Function,
    onMouseup: Function
  },
  setup(props, {
    attrs,
    emit,
    expose
  }) {
    const {
      proxy: self
    } = getCurrentInstance();
    const handleRef = ref();
    const focused = ref(false);
    const ratio = computed(() => (props.value - props.min) / (props.max - props.min));
    let onMouseUpListener;
    onMounted(() => {
      onMouseUpListener = addEventListenerWrap(document, "mouseup", onMouseup);
    });
    onBeforeUnmount(() => {
      onMouseUpListener.remove();
    });
    function onBlur() {
      focused.value = false;
    }
    function onFocus() {
      focused.value = true;
    }
    function onMousedown(e) {
      var _a;
      focused.value = true;
      handleRef.value.focus();
      (_a = props.onMousedown) == null ? void 0 : _a.call(props, e);
    }
    function onMouseup(e) {
      var _a;
      (_a = props.onMouseup) == null ? void 0 : _a.call(props, e);
    }
    return () => {
      const {
        prefixCls,
        value,
        formatTooltip,
        tooltip
      } = props;
      const ariaProps = {
        "aria-valuemin": props.min,
        "aria-valuemax": props.max,
        "aria-valuenow": props.value,
        "aria-disabled": !!props.disabled
      };
      const handleProps = __spreadProps(__spreadValues({
        ref: handleRef,
        class: [`${prefixCls}_handle`, {
          [`${prefixCls}_handle-focused`]: focused.value
        }],
        style: `left: ${ratio.value * 100}%`,
        role: "slider",
        tabindex: 0
      }, ariaProps), {
        onBlur,
        onFocus,
        onMousedown,
        onMouseup
      });
      return createVNode(Tooltip, {
        "title": (formatTooltip == null ? void 0 : formatTooltip(value)) || value,
        "visible": tooltip,
        "placement": "top",
        "trigger": "hover focus",
        "popupClass": `${prefixCls}-tooltip`
      }, {
        default: () => [createVNode("div", handleProps, null)]
      });
    };
  }
});

export { Hanlde as default };
