import { defineComponent, computed, createVNode } from 'vue';
import { filterEmpty } from '../_util/props-util/index.js';
import '../_util/hooks/index.js';
import { castArray } from '../_util/_.js';
import useNamespace from '../_util/hooks/useNameSpace2.js';

var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
const prefixCls = "x-space";
const Space = defineComponent({
  name: prefixCls,
  props: {
    size: {
      type: [Number, String, Array],
      default: "medium"
    },
    vertical: Boolean,
    wrap: {
      default: true
    },
    justify: String,
    align: String,
    itemStyle: [String, Object, Array]
  },
  setup(props, {
    slots
  }) {
    const ns = useNamespace(prefixCls);
    const sizeMap = {
      small: 8,
      medium: 12,
      large: 16
    };
    const gapStyle = computed(() => {
      var _a, _b;
      const size = castArray((_a = sizeMap[props.size]) != null ? _a : props.size);
      return {
        marginRight: size[0] + "px",
        marginBottom: ((_b = size[1]) != null ? _b : size[0]) + "px"
      };
    });
    return () => {
      var _a;
      const items = filterEmpty((_a = slots.default) == null ? void 0 : _a.call(slots));
      const cls = [prefixCls, {
        [ns.m("wrap")]: props.wrap,
        [ns.m("vertical")]: props.vertical
      }];
      const style = __spreadValues({
        justifyContent: props.justify,
        alignItems: props.align
      }, Object.fromEntries(Object.entries(gapStyle.value).map((e) => [e[0], "-" + e[1]])));
      return createVNode("div", {
        "class": cls,
        "style": style
      }, [items.map((item) => createVNode("div", {
        "class": ns.e("item"),
        "style": [props.itemStyle, gapStyle.value]
      }, [item]))]);
    };
  }
});
Space.install = (app) => {
  app.component(Space.name, Space);
};

export { Space as default };
