import { matrix, identity, multiply, flatten } from 'mathjs';

var __pow = Math.pow;
const pinhole = matrix([
  [-1, 0, 0, 0],
  [0, -1, 0, 0],
  [0, 0, 1, 0],
  [0, 0, 0, 1]
]);
function distance(...arr) {
  return Math.sqrt(arr.reduce((t, v) => t += __pow(v, 2), 0));
}
function transform(e, boo) {
  let ev;
  let el;
  if (e.currentTarget) {
    ev = e;
    el = ev.currentTarget;
  } else {
    el = e;
  }
  let offsetX = 0;
  let offsetY = 0;
  if (ev != null) {
    const rect = el.getBoundingClientRect();
    offsetX = ev.clientX - rect.left;
    offsetY = ev.clientY - rect.top;
  }
  let w = el.offsetWidth, w2 = w / 2;
  let h = el.offsetHeight, h2 = h / 2;
  const radius = distance(w2, h2);
  const ratio = distance(offsetX - w2, offsetY - h2) / radius;
  let rotateX = -2 * (offsetY - h2) / h2, rotateY = 2 * (offsetX - w2) / w2;
  let thetX = rotateX * (Math.PI / 180), thetY = rotateY * (Math.PI / 180);
  const rotationYT = matrix([
    [Math.cos(thetY), 0, -Math.sin(thetY), 0],
    [0, 1, 0, 0],
    [Math.sin(thetY), 0, Math.cos(thetY), 0],
    [0, 0, 0, 1]
  ]);
  const rotationXT = matrix([
    [1, 0, 0, 0],
    [0, Math.cos(thetX), Math.sin(thetX), 0],
    [0, -Math.sin(thetX), Math.cos(thetX), 0],
    [0, 0, 0, 1]
  ]);
  const ox = w2, oy = h2, oz = boo ? w2 + radius * 0.02 * (1 - ratio) : w2;
  const transOT = matrix([
    [1, 0, 0, 0],
    [0, 1, 0, 0],
    [0, 0, 1, 0],
    [-ox, -oy, -oz, 1]
  ]);
  const transCenterT = matrix([
    [1, 0, 0, 0],
    [0, 1, 0, 0],
    [0, 0, 1, 0],
    [ox, oy, oz, 1]
  ]);
  let n = -w / 2;
  let f = -w * 1e3;
  let r = 1;
  let l = -1;
  let t = 1;
  let b = -1;
  let m00 = 2 * n / (r - l);
  let m11 = 2 * n / (t - b);
  let m22 = (n + f) / (n - f);
  let m23 = 2 * f * n / (n - f);
  const aperspectT = matrix([
    [m00, 0, 0, 0],
    [0, m11, 0, 0],
    [0, 0, m22, -1],
    [0, 0, m23, 0]
  ]);
  let result = identity(4);
  if (boo) {
    const ox2 = w - offsetX, oy2 = h - offsetY, oz2 = 0;
    const transOT2 = matrix([
      [1, 0, 0, 0],
      [0, 1, 0, 0],
      [0, 0, 1, 0],
      [-ox2, -oy2, -oz2, 1]
    ]);
    const transCenterT2 = matrix([
      [1, 0, 0, 0],
      [0, 1, 0, 0],
      [0, 0, 1, 0],
      [ox2, oy2, oz2, 1]
    ]);
    result = multiply(result, transOT2);
    result = multiply(result, rotationYT);
    result = multiply(result, rotationXT);
    result = multiply(result, transCenterT2);
  }
  result = multiply(result, transOT);
  result = multiply(result, aperspectT);
  result = multiply(result, pinhole);
  result = multiply(result, transCenterT);
  let mStr = flatten(result)._data.join(",");
  el.style.transform = `matrix3d(${mStr}) `;
  el.style.transformOrigin = `0 0`;
}
function addEventListener(el, mousedown, mouseup) {
  const _up = (e) => {
    mouseup(e);
    window.removeEventListener("mouseup", _up);
  };
  const _down = (e) => {
    mousedown(e);
    window.addEventListener("mouseup", _up);
  };
  el.addEventListener("mousedown", _down);
}
const name = "sunken";
const Sunken = {
  name,
  mounted(el) {
    el.style.transition = `unset`;
    transform(el);
    void el.offsetWidth;
    el.style.transition = `transform .1s`;
    addEventListener(el, (e) => {
      transform(e, true);
    }, (e) => {
      transform(el);
    });
  }
};
Sunken.install = (app) => {
  app.directive(Sunken.name, Sunken);
};

export { Sunken as default };
