import { defineComponent, getCurrentInstance, unref, ref, watchEffect, withDirectives, createVNode, resolveDirective } from 'vue';
import { findDOMNode } from '../_util/props-util/index.js';
import useResizeObserver from '../_util/hooks/useResizeObserver.js';
import BorderLight from '../border-light/index.js';

const preCls = "x-tabs";
var Tabbar = defineComponent({
  name: preCls,
  props: {
    value: [String, Number, Object],
    type: String,
    tabs: Object
  },
  directives: {
    [BorderLight.name]: BorderLight
  },
  emits: ["change"],
  setup(props, {
    emit
  }) {
    const {
      proxy: vm
    } = getCurrentInstance();
    function getActiveRef() {
      return vm.$refs[`tab_${unref(props.value)}`];
    }
    function updateBarStyle(tabEl) {
      if (!tabEl)
        return;
      const container = findDOMNode(vm), scrollLeft = container == null ? void 0 : container.scrollLeft, rect = container == null ? void 0 : container.getBoundingClientRect(), rect2 = tabEl == null ? void 0 : tabEl.getBoundingClientRect();
      barStyleRef.value = {
        left: ((rect2 == null ? void 0 : rect2.left) - rect.left + scrollLeft || 0) + "px",
        width: Math.round((rect2 == null ? void 0 : rect2.width) || 0) + "px"
      };
    }
    useResizeObserver(() => {
      updateBarStyle(getActiveRef());
    });
    const barStyleRef = ref();
    watchEffect(() => {
      void props.tabs;
      void props.type;
      updateBarStyle(getActiveRef());
    });
    function onClick(key) {
      emit("change", key);
    }
    function items() {
      return props.tabs.value.map((tab, i) => {
        var _a, _b, _c, _d, _e, _f;
        const key = (_b = (_a = tab.name) != null ? _a : tab.label) != null ? _b : i;
        const isActive = key == unref(props.value);
        let node = withDirectives(createVNode("div", {
          "role": "tab",
          "aria-selected": isActive,
          "tabindex": i,
          "class": `${preCls}_tab ${preCls}_tab-${isActive ? "active" : "inactive"}`,
          "key": key,
          "ref": `tab_${key}`,
          "onClick": () => onClick(key)
        }, [(_f = (_e = (_d = (_c = tab.$slots).label) == null ? void 0 : _d.call(_c)) != null ? _e : tab.label) != null ? _f : key]), [[resolveDirective("border-light"), {
          borderWidth: 1,
          style: {
            opacity: 0.2
          }
        }]]);
        return node;
      });
    }
    return () => {
      return createVNode("div", {
        "role": "tablist",
        "class": `${preCls}_nav ${preCls}_nav-${props.type}`
      }, [items(), createVNode("div", {
        "class": `${preCls}_bar`,
        "style": barStyleRef.value
      }, null)]);
    };
  }
});

export { Tabbar as default };
