import { defineComponent, createVNode, withDirectives, resolveDirective } from 'vue';
import Sunken from '../sunken/index.js';
import { getComponent, render } from '../_util/props-util/index.js';
import '../icon/index.js';
import Icon from '../icon/Icon.js';

const prefixCls = "x-tag";
const Tag = defineComponent({
  name: prefixCls,
  props: {
    closable: Boolean,
    closeIcon: [String, Object],
    color: String,
    icon: Object,
    round: Boolean,
    bordered: Boolean,
    nowrap: Boolean,
    size: {
      type: String,
      default: "small"
    },
    type: {
      type: String,
      default: "default"
    },
    onClose: Function
  },
  emits: ["close"],
  directives: {
    [Sunken.name]: Sunken
  },
  setup(props, {
    slots,
    emit
  }) {
    function onClose(e) {
      e.stopPropagation();
      emit("close", e);
    }
    function onMousedown(e) {
      e.stopPropagation();
    }
    function renderCloseNode(vm) {
      let cls = `${prefixCls}-close-icon`;
      if (props.closable) {
        let node, icon = props.closeIcon || "cross";
        if (typeof icon === "string") {
          node = createVNode(Icon, {
            "class": cls,
            "type": icon
          }, null);
        } else {
          node = createVNode("div", {
            "class": cls
          }, [getComponent(vm, "closeIcon")]);
        }
        node.props.onClick = onClose;
        node.props.onMousedown = onMousedown;
        return node;
      }
    }
    return (vm) => {
      var _a;
      const {
        color,
        size,
        type
      } = props;
      const style = {
        backgroundColor: color
      };
      const cls = [prefixCls, `${prefixCls}-${size}`, `${prefixCls}-${type}`, {
        [`${prefixCls}-round`]: props.round,
        [`${prefixCls}-bordered`]: props.bordered,
        [`${prefixCls}-nowrap`]: props.nowrap
      }];
      const iconNode = render(props.icon);
      return withDirectives(createVNode("span", {
        "class": cls,
        "style": style
      }, [iconNode, (_a = slots.default) == null ? void 0 : _a.call(slots), renderCloseNode(vm)]), [[resolveDirective("sunken")]]);
    };
  }
});
Tag.install = (app) => {
  app.component(Tag.name, Tag);
};

export { Tag as default };
