import { defineComponent, reactive, computed, ref, withDirectives, createVNode, vShow } from 'vue';

function getPageY(e) {
  return "touches" in e ? e.touches[0].pageY : e.pageY;
}
var ScrollBar = defineComponent({
  name: "scroll-bar",
  props: {
    prefixCls: String,
    height: Number,
    scrollTop: Number,
    scrollHeight: Number,
    onScroll: Function
  },
  setup(props, {
    attrs,
    expose
  }) {
    const {
      prefixCls
    } = props;
    const state = reactive({});
    const showScroll = computed(() => {
      return props.scrollHeight > props.height;
    });
    const thumbHeight = computed(() => {
      const r = props.height / props.scrollHeight;
      let h = Math.min(props.height * r, props.height * 0.75);
      h = Math.max(h, 16);
      return h;
    });
    const _scrollTop = ref(0);
    function getTop() {
      const range = props.height - thumbHeight.value;
      const percent = _scrollTop.value / (props.scrollHeight - props.height);
      return _scrollTop.value + percent * range;
    }
    expose({
      setScrollTop: (val) => _scrollTop.value = val
    });
    let startPageY = 0, startTop = 0;
    function onMousedown(e) {
      startPageY = getPageY(e);
      startTop = getTop();
      window.addEventListener("mousemove", onMousemove);
      window.addEventListener("mouseup", onMouseup);
      window.addEventListener("touchmove", onMousemove);
      window.addEventListener("touchend", onMouseup);
    }
    function onMousemove(e) {
      var _a;
      const offsetY = getPageY(e) - startPageY;
      const scrollTop = (startTop + offsetY) / (props.height - thumbHeight.value) * props.scrollHeight;
      (_a = props.onScroll) == null ? void 0 : _a.call(props, scrollTop);
    }
    function onMouseup(e) {
      window.removeEventListener("mousemove", onMousemove);
      window.removeEventListener("mouseup", onMouseup);
      window.removeEventListener("touchmove", onMousemove);
      window.removeEventListener("touchend", onMouseup);
    }
    return () => {
      const top = getTop();
      const style = `position:absolute;height:${thumbHeight.value}px; top:${top}px;`;
      return withDirectives(createVNode("div", {
        "class": `${prefixCls}_scrollbar`
      }, [createVNode("div", {
        "class": `${prefixCls}_scrollbar-thumb`,
        "style": style,
        "onMousedown": onMousedown,
        "onTouchstart": onMousedown
      }, null)]), [[vShow, showScroll.value]]);
    };
  }
});

export { ScrollBar as default };
